@@ -6,6 +6,7 @@
 #' with the same structure as [stats::model.matrix.default()].
 #'
 #' @param model a model object
+#' @param ... additional arguments passed to [stats::model.matrix()]
 #' @export
 #' @family model_helpers
 #' @seealso [stats::model.matrix()]
@@ -13,18 +14,18 @@
 #' lm(hp ~ mpg + factor(cyl), mtcars) %>%
 #'   model_get_model_matrix() %>%
 #'   head()
-model_get_model_matrix <- function(model) {
+model_get_model_matrix <- function(model, ...) {
   UseMethod("model_get_model_matrix")
 }
 
 #' @export
 #' @rdname model_get_model_matrix
-model_get_model_matrix.default <- function(model) {
+model_get_model_matrix.default <- function(model, ...) {
   tryCatch(
-    stats::model.matrix(model),
+    stats::model.matrix(model, ...),
     error = function(e) {
       tryCatch( # test second approach
-        stats::model.matrix(stats::terms(model), model$model),
+        stats::model.matrix(stats::terms(model), model$model, ...),
         error = function(e) {
           NULL
         }
@@ -39,14 +40,20 @@ model_get_model_matrix.default <- function(model) {
 # consistent with the terms names when contrasts other
 # than treatment are used, resulting in an issue for
 # the identification of variables
-model_get_model_matrix.multinom <- function(model) {
-  mm <- stats::model.matrix(model)
+model_get_model_matrix.multinom <- function(model, ...) {
+  mm <- stats::model.matrix(model, ...)
   colnames(mm) <- colnames(stats::coef(model))
   mm
 }
 
 #' @export
 #' @rdname model_get_model_matrix
-model_get_model_matrix.clm <- function(model) {
-  stats::model.matrix(model)[[1]]
+model_get_model_matrix.clm <- function(model, ...) {
+  stats::model.matrix(model, ...)[[1]]
+}
+
+#' @export
+#' @rdname model_get_model_matrix
+model_get_model_matrix.brmsfit <- function(model, ...) {
+  model %>% brms::standata() %>% purrr::pluck("X")
 }
